.. _`documentation`: https://boozelib.readthedocs.org/
.. _`formulas`: https://boozelib.readthedocs.org/en/latest/formulas.html
.. _`issue tracker`: https://github.com/brutus/boozelib/issues
.. _`nox`: https://nox.thea.codes/
.. _`pipenv`: https://pipenv.pypa.io/
.. _`pypi`: https://pypi.org/project/BoozeLib/
.. _`pytest`: https://docs.pytest.org/
